import ec2 = require('@aws-cdk/aws-ec2');
import elb = require('@aws-cdk/aws-elasticloadbalancing');
import { Construct } from '@aws-cdk/core';
import { BaseService, BaseServiceProps, IService } from '../base/base-service';
import { TaskDefinition } from '../base/task-definition';
import { PlacementConstraint, PlacementStrategy } from '../placement';
/**
 * Properties to define an ECS service
 */
export interface Ec2ServiceProps extends BaseServiceProps {
    /**
     * Task Definition used for running tasks in the service
     *
     * [disable-awslint:ref-via-interface]
     */
    readonly taskDefinition: TaskDefinition;
    /**
     * Assign public IP addresses to each task
     *
     * @default - Use subnet default.
     */
    readonly assignPublicIp?: boolean;
    /**
     * In what subnets to place the task's ENIs
     *
     * (Only applicable in case the TaskDefinition is configured for AwsVpc networking)
     *
     * @default - Private subnets.
     */
    readonly vpcSubnets?: ec2.SubnetSelection;
    /**
     * Existing security group to use for the task's ENIs
     *
     * (Only applicable in case the TaskDefinition is configured for AwsVpc networking)
     *
     * @default - A new security group is created.
     */
    readonly securityGroup?: ec2.ISecurityGroup;
    /**
     * Placement constraints
     *
     * @default - No constraints.
     */
    readonly placementConstraints?: PlacementConstraint[];
    /**
     * Placement strategies
     *
     * @default - No strategies.
     */
    readonly placementStrategies?: PlacementStrategy[];
    /**
     * Deploy exactly one task on each instance in your cluster.
     *
     * When using this strategy, do not specify a desired number of tasks or any
     * task placement strategies.
     *
     * @default false
     */
    readonly daemon?: boolean;
}
export interface IEc2Service extends IService {
}
/**
 * Start a service on an ECS cluster
 *
 * @resource AWS::ECS::Service
 */
export declare class Ec2Service extends BaseService implements IEc2Service, elb.ILoadBalancerTarget {
    static fromEc2ServiceArn(scope: Construct, id: string, ec2ServiceArn: string): IEc2Service;
    private readonly constraints;
    private readonly strategies;
    private readonly daemon;
    constructor(scope: Construct, id: string, props: Ec2ServiceProps);
    /**
     * Add one or more placement strategies
     */
    addPlacementStrategies(...strategies: PlacementStrategy[]): void;
    /**
     * Add one or more placement strategies
     */
    addPlacementConstraints(...constraints: PlacementConstraint[]): void;
    /**
     * Register this service as the target of a Classic Load Balancer
     *
     * Don't call this. Call `loadBalancer.addTarget()` instead.
     */
    attachToClassicLB(loadBalancer: elb.LoadBalancer): void;
    /**
     * Validate this Ec2Service
     */
    protected validate(): string[];
}
/**
 * Built-in container instance attributes
 */
export declare class BuiltInAttributes {
    /**
     * The Instance ID of the instance
     */
    static readonly INSTANCE_ID = "instanceId";
    /**
     * The AZ where the instance is running
     */
    static readonly AVAILABILITY_ZONE = "attribute:ecs.availability-zone";
    /**
     * The AMI ID of the instance
     */
    static readonly AMI_ID = "attribute:ecs.ami-id";
    /**
     * The instance type
     */
    static readonly INSTANCE_TYPE = "attribute:ecs.instance-type";
    /**
     * The OS type
     *
     * Either 'linux' or 'windows'.
     */
    static readonly OS_TYPE = "attribute:ecs.os-type";
}
