import { CfnService } from "./ecs.generated";
/**
 * Instance resource used for bin packing
 */
export declare enum BinPackResource {
    /**
     * Fill up hosts' CPU allocations first
     */
    CPU = "cpu",
    /**
     * Fill up hosts' memory allocations first
     */
    MEMORY = "memory"
}
/**
 * An ECS placement strategy
 *
 * Tasks will preferentially be placed on instances that match these rules.
 */
export declare class PlacementStrategy {
    private readonly json;
    /**
     * Try to place tasks spread across instances
     */
    static spreadAcrossInstances(): PlacementStrategy;
    /**
     * Try to place tasks spread across instances based on given attributes
     *
     * You can use one of the built-in attributes found on `BuiltInAttributes`
     * or supply your own custom instance attributes. If more than one attribute
     * is supplied, spreading is done in order.
     *
     * @default attributes instanceId
     */
    static spreadAcross(...fields: string[]): PlacementStrategy;
    /**
     * Try to place tasks on instances with the least amount of CPU
     *
     * This ensures the total consumption of CPU is lowest
     */
    static packedByCpu(): PlacementStrategy;
    /**
     * Try to place tasks on instances with the least amount of memory
     *
     * This ensures the total consumption of memory is lowest
     */
    static packedByMemory(): PlacementStrategy;
    /**
     * Try to place tasks on instances with the least amount of indicated resource available
     *
     * This ensures the total consumption of this resource is lowest.
     */
    static packedBy(resource: BinPackResource): PlacementStrategy;
    /**
     * Place tasks randomly across the available instances.
     */
    static randomly(): PlacementStrategy;
    private constructor();
    /**
     * Return the placement JSON
     */
    toJson(): CfnService.PlacementStrategyProperty[];
}
/**
 * An ECS placement constraint
 *
 * Tasks will only be placed on instances that match these rules.
 */
export declare class PlacementConstraint {
    private readonly json;
    /**
     * Place every task on a different instance
     */
    static distinctInstances(): PlacementConstraint;
    /**
     * Place tasks only on instances matching the given query expression
     *
     * You can specify multiple expressions in one call. The tasks will only
     * be placed on instances matching all expressions.
     *
     * @see https://docs.aws.amazon.com/AmazonECS/latest/developerguide/cluster-query-language.html
     */
    static memberOf(...expressions: string[]): PlacementConstraint;
    private constructor();
    /**
     * Return the placement JSON
     */
    toJson(): CfnService.PlacementConstraintProperty[];
}
